@@ -1,10 +1,10 @@
 # Copyrights 2003-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.00.
 package OODoc::Format::Pod;
 use vars '$VERSION';
-$VERSION = '0.99';
+$VERSION = '1.00';
 use base 'OODoc::Format';
 
 use strict;
@@ -40,9 +40,9 @@ sub createManual($@)
     my $options  = $args{format_options} || [];
 
     print $manual->orderedChapters." chapters in $manual\n" if $verbose>=3;
-    my $podname  = my $tmpname = $manual->source;
+    my $podname  = $manual->source;
     $podname     =~ s/\.pm$/.pod/;
-    $tmpname     =~ s/\.pm$/.tmp/;
+    my $tmpname  =  $podname . 't';
 
     my $tmpfile  = File::Spec->catfile($self->workdir, $tmpname);
     my $podfile  = File::Spec->catfile($self->workdir, $podname);
@@ -344,7 +344,7 @@ sub showOptionUse(@)
     my $params = $option->parameters;
     $params    =~ s/\s+$//;
     $params    =~ s/^\s+//;
-    $params    = " $params" if length $params;
+    $params    = " => $params" if length $params;
  
     $output->print("\n. $option$params\n");
     $self;
