@@ -1,11 +1,11 @@
 # Copyrights 2003-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.00.
 
 package OODoc::Manifest;
 use vars '$VERSION';
-$VERSION = '0.99';
+$VERSION = '1.00';
 use base 'OODoc::Object';
 
 use strict;
@@ -69,7 +69,7 @@ sub read()
     my @dist = $file->getlines;
     $file->close;
 
-    chomp foreach @dist;
+    s/\s+.*\n?$// for @dist;
     $self->{O_files}{$_}++ foreach @dist;
     $self;
 }
